==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/netadm/netadm.m <==
extern const char **_dictionary_netadm;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_netadm;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_netadm("netadm",_dictionary_netadm,48,0);\
	void dummy_dict_netadm(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_netadm[id]
	#define MSG_B(id,m,n)	_dictionary_netadm[id]
	#define MSG_R(id)	_dictionary_netadm[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_netadm,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_netadm,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_netadm,id)
#endif
#define M_NETADM	0
#define T_USAGE	1
#define F_ID	2
#define T_MEMBERS	3
#define T_SUBSYS	4
#define T_CLUSDEF	5
#define I_CLUSDEF	6
#define E_NOSPACEID	7
#define F_DESC	8
#define T_CLUSTERS	9
#define I_CLUSTERS	10
#define M_ADMINGROUPS	11
#define M_ADMINTREE	12
#define M_REMOTEADMIN	13
#define T_NETADMIN	14
#define T_NETADMINT	15
#define I_NETADMINT	16
#define E_NOTREE	17
#define F_TREENAME	18
#define I_ADDTREE	19
#define T_ADDTREE	20
#define E_NOSPACE	21
#define T_ADMINTREES	22
#define I_ADMINTREES	23
#define F_ADMTREE	24
#define E_CREATEDIR	25
#define B_PUBLISH	26
#define N_PUBLISHDONE	27
#define I_PUBLISHING	28
#define M_PUBLISHING	29
#define I_IMPORTING	30
#define P_IMPORT	31
#define E_OUTOFSYNC	32
#define E_EXPORTERR	33
#define E_STAT	34
#define F_ROOTPASS	35
#define I_EXPORTINGTO	36
#define B_EXPORT	37
#define N_UPDATED	38
#define P_ROOTONLY	39
#define N_GUIMODEONLY	40
#define F_REMHOST	41
#define T_REMADMIN	42
#define N_CONNECTING	43
#define I_EXPORTOK	44
#define T_EXPORTOK	45
#define I_DEBUG	46
#define H_GROUPES	47

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/netadm/netadm.m <==
extern const char **_dictionary_netadm;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_netadm;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_netadm("netadm",_dictionary_netadm,54,0);\
	void dummy_dict_netadm(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_netadm[id]
	#define MSG_B(id,m,n)	_dictionary_netadm[id]
	#define MSG_R(id)	_dictionary_netadm[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_netadm,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_netadm,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_netadm,id)
#endif
#define M_NETADM	0
#define T_USAGE	1
#define F_ID	2
#define T_MEMBERS	3
#define T_SUBSYS	4
#define T_CLUSDEF	5
#define I_CLUSDEF	6
#define E_NOSPACEID	7
#define F_DESC	8
#define T_CLUSTERS	9
#define I_CLUSTERS	10
#define M_ADMINGROUPS	11
#define M_ADMINTREE	12
#define M_REMOTEADMIN	13
#define T_NETADMIN	14
#define T_NETADMINT	15
#define I_NETADMINT	16
#define E_NOTREE	17
#define F_TREENAME	18
#define I_ADDTREE	19
#define T_ADDTREE	20
#define E_NOSPACE	21
#define T_ADMINTREES	22
#define I_ADMINTREES	23
#define F_ADMTREE	24
#define E_CREATEDIR	25
#define B_PUBLISH	26
#define N_PUBLISHDONE	27
#define I_PUBLISHING	28
#define M_PUBLISHING	29
#define I_IMPORTING	30
#define P_IMPORT	31
#define E_OUTOFSYNC	32
#define E_EXPORTERR	33
#define E_STAT	34
#define F_ROOTPASS	35
#define I_EXPORTINGTO	36
#define B_EXPORT	37
#define N_UPDATED	38
#define P_ROOTONLY	39
#define N_GUIMODEONLY	40
#define F_REMHOST	41
#define T_REMADMIN	42
#define N_CONNECTING	43
#define I_EXPORTOK	44
#define T_EXPORTOK	45
#define I_DEBUG	46
#define H_GROUPES	47
#define E_CANTEXEC	48
#define F_COMMAND	49
#define I_SSH	50
#define I_RLOGIN	51
#define E_NOCMDTOEXP	52
#define E_ERRTRANSPORT	53
